@@ -9,9 +9,15 @@
 #' aiming for efficient and robust implementations of functions, typically
 #' applied to unweighted trees (i.e. those without edge lengths).
 #'
+#' Full documentation is available [online](https://ms609.github.io/TreeTools/).
+#'
 #' @keywords internal
 "_PACKAGE"
 
+# Suppress "NOTE: Nothing imported from Rdpack":
+#' @importFrom Rdpack reprompt
+NULL
+
 # The following block is used by usethis to automatically manage
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
